# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.predict.predict_eval import predict_eval_api_service_pb2 as cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2


class PredictEvalServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get = channel.unary_unary(
        '/ai.cogneed.api.predict.predicteval.PredictEvalService/get',
        request_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetResponse.FromString,
        )
    self.set = channel.unary_unary(
        '/ai.cogneed.api.predict.predicteval.PredictEvalService/set',
        request_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetResponse.FromString,
        )


class PredictEvalServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def set(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PredictEvalServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get': grpc.unary_unary_rpc_method_handler(
          servicer.get,
          request_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetRequest.FromString,
          response_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetResponse.SerializeToString,
      ),
      'set': grpc.unary_unary_rpc_method_handler(
          servicer.set,
          request_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetRequest.FromString,
          response_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.predicteval.PredictEvalService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
