# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/audio-web-middleware/audio-web-middleware-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import common_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/audio-web-middleware/audio-web-middleware-service.proto',
  package='ai.cogneed.api.audio.web',
  syntax='proto3',
  serialized_options=_b('\n\030ai.cogneed.api.audio.webP\001'),
  serialized_pb=_b('\nScogneed-protos/audio-stream/audio-web-middleware/audio-web-middleware-service.proto\x12\x18\x61i.cogneed.api.audio.web\x1a/cogneed-protos/audio-stream/common/common.proto\"M\n\x0eStatusResponse\x12;\n\x0bstatus_code\x18\x01 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.StatusCode\")\n\x11\x45ndSessionRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"(\n\x10SubscribeRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"8\n\x0fWebAudioRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x14\n\x0csession_uuid\x18\x02 \x01(\t\"&\n\x0eUnstackRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"T\n\x0fUnstackResponse\x12\x41\n\ndetections\x18\x01 \x03(\x0b\x32-.ai.cogneed.cloud.speech.v1.DetectionResponse\"\x8a\x01\n\x16StartWebSessionRequest\x12\x37\n\tuser_info\x18\x01 \x01(\x0b\x32$.ai.cogneed.cloud.speech.v1.UserInfo\x12\x37\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\'.ai.cogneed.cloud.speech.v1.AudioFormat\"R\n\x17StartWebSessionResponse\x12\x13\n\tcall_uuid\x18\x01 \x01(\tH\x00\x12\x17\n\rmessage_error\x18\x02 \x01(\tH\x00\x42\t\n\x07\x63ontent2\xa7\x03\n\x0fWebAudioService\x12l\n\x05start\x12\x30.ai.cogneed.api.audio.web.StartWebSessionRequest\x1a\x31.ai.cogneed.api.audio.web.StartWebSessionResponse\x12\\\n\x05\x61udio\x12).ai.cogneed.api.audio.web.WebAudioRequest\x1a(.ai.cogneed.api.audio.web.StatusResponse\x12h\n\tsubscribe\x12*.ai.cogneed.api.audio.web.SubscribeRequest\x1a-.ai.cogneed.cloud.speech.v1.DetectionResponse0\x01\x12^\n\x07unstack\x12(.ai.cogneed.api.audio.web.UnstackRequest\x1a).ai.cogneed.api.audio.web.UnstackResponseB\x1c\n\x18\x61i.cogneed.api.audio.webP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.DESCRIPTOR,])




_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='ai.cogneed.api.audio.web.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code', full_name='ai.cogneed.api.audio.web.StatusResponse.status_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=239,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.api.audio.web.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.EndSessionRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=282,
)


_SUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='SubscribeRequest',
  full_name='ai.cogneed.api.audio.web.SubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.SubscribeRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=324,
)


_WEBAUDIOREQUEST = _descriptor.Descriptor(
  name='WebAudioRequest',
  full_name='ai.cogneed.api.audio.web.WebAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.web.WebAudioRequest.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.WebAudioRequest.session_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=382,
)


_UNSTACKREQUEST = _descriptor.Descriptor(
  name='UnstackRequest',
  full_name='ai.cogneed.api.audio.web.UnstackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.UnstackRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=422,
)


_UNSTACKRESPONSE = _descriptor.Descriptor(
  name='UnstackResponse',
  full_name='ai.cogneed.api.audio.web.UnstackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detections', full_name='ai.cogneed.api.audio.web.UnstackResponse.detections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=508,
)


_STARTWEBSESSIONREQUEST = _descriptor.Descriptor(
  name='StartWebSessionRequest',
  full_name='ai.cogneed.api.audio.web.StartWebSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_info', full_name='ai.cogneed.api.audio.web.StartWebSessionRequest.user_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='ai.cogneed.api.audio.web.StartWebSessionRequest.format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=649,
)


_STARTWEBSESSIONRESPONSE = _descriptor.Descriptor(
  name='StartWebSessionResponse',
  full_name='ai.cogneed.api.audio.web.StartWebSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.web.StartWebSessionResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_error', full_name='ai.cogneed.api.audio.web.StartWebSessionResponse.message_error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.audio.web.StartWebSessionResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=651,
  serialized_end=733,
)

_STATUSRESPONSE.fields_by_name['status_code'].enum_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._STATUSCODE
_UNSTACKRESPONSE.fields_by_name['detections'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._DETECTIONRESPONSE
_STARTWEBSESSIONREQUEST.fields_by_name['user_info'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._USERINFO
_STARTWEBSESSIONREQUEST.fields_by_name['format'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._AUDIOFORMAT
_STARTWEBSESSIONRESPONSE.oneofs_by_name['content'].fields.append(
  _STARTWEBSESSIONRESPONSE.fields_by_name['call_uuid'])
_STARTWEBSESSIONRESPONSE.fields_by_name['call_uuid'].containing_oneof = _STARTWEBSESSIONRESPONSE.oneofs_by_name['content']
_STARTWEBSESSIONRESPONSE.oneofs_by_name['content'].fields.append(
  _STARTWEBSESSIONRESPONSE.fields_by_name['message_error'])
_STARTWEBSESSIONRESPONSE.fields_by_name['message_error'].containing_oneof = _STARTWEBSESSIONRESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRequest'] = _SUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['WebAudioRequest'] = _WEBAUDIOREQUEST
DESCRIPTOR.message_types_by_name['UnstackRequest'] = _UNSTACKREQUEST
DESCRIPTOR.message_types_by_name['UnstackResponse'] = _UNSTACKRESPONSE
DESCRIPTOR.message_types_by_name['StartWebSessionRequest'] = _STARTWEBSESSIONREQUEST
DESCRIPTOR.message_types_by_name['StartWebSessionResponse'] = _STARTWEBSESSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.SubscribeRequest)
  ))
_sym_db.RegisterMessage(SubscribeRequest)

WebAudioRequest = _reflection.GeneratedProtocolMessageType('WebAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _WEBAUDIOREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.WebAudioRequest)
  ))
_sym_db.RegisterMessage(WebAudioRequest)

UnstackRequest = _reflection.GeneratedProtocolMessageType('UnstackRequest', (_message.Message,), dict(
  DESCRIPTOR = _UNSTACKREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.UnstackRequest)
  ))
_sym_db.RegisterMessage(UnstackRequest)

UnstackResponse = _reflection.GeneratedProtocolMessageType('UnstackResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNSTACKRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.UnstackResponse)
  ))
_sym_db.RegisterMessage(UnstackResponse)

StartWebSessionRequest = _reflection.GeneratedProtocolMessageType('StartWebSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _STARTWEBSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.StartWebSessionRequest)
  ))
_sym_db.RegisterMessage(StartWebSessionRequest)

StartWebSessionResponse = _reflection.GeneratedProtocolMessageType('StartWebSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _STARTWEBSESSIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.StartWebSessionResponse)
  ))
_sym_db.RegisterMessage(StartWebSessionResponse)


DESCRIPTOR._options = None

_WEBAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='WebAudioService',
  full_name='ai.cogneed.api.audio.web.WebAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=736,
  serialized_end=1159,
  methods=[
  _descriptor.MethodDescriptor(
    name='start',
    full_name='ai.cogneed.api.audio.web.WebAudioService.start',
    index=0,
    containing_service=None,
    input_type=_STARTWEBSESSIONREQUEST,
    output_type=_STARTWEBSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='audio',
    full_name='ai.cogneed.api.audio.web.WebAudioService.audio',
    index=1,
    containing_service=None,
    input_type=_WEBAUDIOREQUEST,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='subscribe',
    full_name='ai.cogneed.api.audio.web.WebAudioService.subscribe',
    index=2,
    containing_service=None,
    input_type=_SUBSCRIBEREQUEST,
    output_type=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._DETECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='unstack',
    full_name='ai.cogneed.api.audio.web.WebAudioService.unstack',
    index=3,
    containing_service=None,
    input_type=_UNSTACKREQUEST,
    output_type=_UNSTACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBAUDIOSERVICE)

DESCRIPTOR.services_by_name['WebAudioService'] = _WEBAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
