# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/audio-stream-recorder/audio-stream-recorder-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/audio-stream-recorder/audio-stream-recorder-service.proto',
  package='ai.cogneed.record.v1',
  syntax='proto3',
  serialized_options=_b('\n\024ai.cogneed.record.v1P\001'),
  serialized_pb=_b('\nUcogneed-protos/audio-stream/audio-stream-recorder/audio-stream-recorder-service.proto\x12\x14\x61i.cogneed.record.v1\"B\n\rRecordRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"\"\n\x12\x43onsolidateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x1a\n\x08Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x32\xb7\x01\n\rRecordService\x12M\n\x06record\x12#.ai.cogneed.record.v1.RecordRequest\x1a\x1e.ai.cogneed.record.v1.Response\x12W\n\x0b\x63onsolidate\x12(.ai.cogneed.record.v1.ConsolidateRequest\x1a\x1e.ai.cogneed.record.v1.ResponseB\x18\n\x14\x61i.cogneed.record.v1P\x01\x62\x06proto3')
)




_RECORDREQUEST = _descriptor.Descriptor(
  name='RecordRequest',
  full_name='ai.cogneed.record.v1.RecordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.record.v1.RecordRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.record.v1.RecordRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.record.v1.RecordRequest.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=177,
)


_CONSOLIDATEREQUEST = _descriptor.Descriptor(
  name='ConsolidateRequest',
  full_name='ai.cogneed.record.v1.ConsolidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.record.v1.ConsolidateRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=213,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='ai.cogneed.record.v1.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ai.cogneed.record.v1.Response.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=241,
)

DESCRIPTOR.message_types_by_name['RecordRequest'] = _RECORDREQUEST
DESCRIPTOR.message_types_by_name['ConsolidateRequest'] = _CONSOLIDATEREQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecordRequest = _reflection.GeneratedProtocolMessageType('RecordRequest', (_message.Message,), dict(
  DESCRIPTOR = _RECORDREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_recorder.audio_stream_recorder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.record.v1.RecordRequest)
  ))
_sym_db.RegisterMessage(RecordRequest)

ConsolidateRequest = _reflection.GeneratedProtocolMessageType('ConsolidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSOLIDATEREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_recorder.audio_stream_recorder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.record.v1.ConsolidateRequest)
  ))
_sym_db.RegisterMessage(ConsolidateRequest)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_recorder.audio_stream_recorder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.record.v1.Response)
  ))
_sym_db.RegisterMessage(Response)


DESCRIPTOR._options = None

_RECORDSERVICE = _descriptor.ServiceDescriptor(
  name='RecordService',
  full_name='ai.cogneed.record.v1.RecordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=244,
  serialized_end=427,
  methods=[
  _descriptor.MethodDescriptor(
    name='record',
    full_name='ai.cogneed.record.v1.RecordService.record',
    index=0,
    containing_service=None,
    input_type=_RECORDREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='consolidate',
    full_name='ai.cogneed.record.v1.RecordService.consolidate',
    index=1,
    containing_service=None,
    input_type=_CONSOLIDATEREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECORDSERVICE)

DESCRIPTOR.services_by_name['RecordService'] = _RECORDSERVICE

# @@protoc_insertion_point(module_scope)
