# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/public/audio/audio_api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/public/audio/audio_api.proto',
  package='ai.cogneed.audio.api',
  syntax='proto3',
  serialized_options=_b('\n\024ai.cogneed.audio.apiP\001'),
  serialized_pb=_b('\n+cogneed-protos/public/audio/audio_api.proto\x12\x14\x61i.cogneed.audio.api\"<\n\tAudioInfo\x12/\n\x05\x63odec\x18\x01 \x01(\x0e\x32 .ai.cogneed.audio.api.AudioCodec\"#\n\x11PersistenceConfig\x12\x0e\n\x06record\x18\x01 \x01(\x08\"(\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\xc1\x01\n\x12InitSessionRequest\x12\x31\n\tuser_info\x18\x01 \x01(\x0b\x32\x1e.ai.cogneed.audio.api.UserInfo\x12\x33\n\naudio_info\x18\x02 \x01(\x0b\x32\x1f.ai.cogneed.audio.api.AudioInfo\x12\x43\n\x12persistence_config\x18\x03 \x01(\x0b\x32\'.ai.cogneed.audio.api.PersistenceConfig\"\x1c\n\tAudioBlob\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x8b\x01\n\x12\x41udioDetectRequest\x12\x38\n\x04init\x18\x01 \x01(\x0b\x32(.ai.cogneed.audio.api.InitSessionRequestH\x00\x12\x30\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1f.ai.cogneed.audio.api.AudioBlobH\x00\x42\t\n\x07request\"9\n\x11\x44\x65tectionResponse\x12\x13\n\x0bmillisecond\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t**\n\nAudioCodec\x12\r\n\tG711_ULAW\x10\x00\x12\r\n\tG711_ALAW\x10\x01\x32{\n\x12StreamAudioService\x12\x65\n\x0cstream_audio\x12(.ai.cogneed.audio.api.AudioDetectRequest\x1a\'.ai.cogneed.audio.api.DetectionResponse(\x01\x30\x01\x42\x18\n\x14\x61i.cogneed.audio.apiP\x01\x62\x06proto3')
)

_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='ai.cogneed.audio.api.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='G711_ULAW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G711_ALAW', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=637,
  serialized_end=679,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCODEC)

AudioCodec = enum_type_wrapper.EnumTypeWrapper(_AUDIOCODEC)
G711_ULAW = 0
G711_ALAW = 1



_AUDIOINFO = _descriptor.Descriptor(
  name='AudioInfo',
  full_name='ai.cogneed.audio.api.AudioInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.audio.api.AudioInfo.codec', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=129,
)


_PERSISTENCECONFIG = _descriptor.Descriptor(
  name='PersistenceConfig',
  full_name='ai.cogneed.audio.api.PersistenceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='ai.cogneed.audio.api.PersistenceConfig.record', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=166,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='ai.cogneed.audio.api.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.audio.api.UserInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.audio.api.UserInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=208,
)


_INITSESSIONREQUEST = _descriptor.Descriptor(
  name='InitSessionRequest',
  full_name='ai.cogneed.audio.api.InitSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_info', full_name='ai.cogneed.audio.api.InitSessionRequest.user_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_info', full_name='ai.cogneed.audio.api.InitSessionRequest.audio_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.audio.api.InitSessionRequest.persistence_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=404,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.audio.api.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.audio.api.AudioBlob.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=434,
)


_AUDIODETECTREQUEST = _descriptor.Descriptor(
  name='AudioDetectRequest',
  full_name='ai.cogneed.audio.api.AudioDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='init', full_name='ai.cogneed.audio.api.AudioDetectRequest.init', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='ai.cogneed.audio.api.AudioDetectRequest.audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='ai.cogneed.audio.api.AudioDetectRequest.request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=437,
  serialized_end=576,
)


_DETECTIONRESPONSE = _descriptor.Descriptor(
  name='DetectionResponse',
  full_name='ai.cogneed.audio.api.DetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='ai.cogneed.audio.api.DetectionResponse.millisecond', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.audio.api.DetectionResponse.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=635,
)

_AUDIOINFO.fields_by_name['codec'].enum_type = _AUDIOCODEC
_INITSESSIONREQUEST.fields_by_name['user_info'].message_type = _USERINFO
_INITSESSIONREQUEST.fields_by_name['audio_info'].message_type = _AUDIOINFO
_INITSESSIONREQUEST.fields_by_name['persistence_config'].message_type = _PERSISTENCECONFIG
_AUDIODETECTREQUEST.fields_by_name['init'].message_type = _INITSESSIONREQUEST
_AUDIODETECTREQUEST.fields_by_name['audio'].message_type = _AUDIOBLOB
_AUDIODETECTREQUEST.oneofs_by_name['request'].fields.append(
  _AUDIODETECTREQUEST.fields_by_name['init'])
_AUDIODETECTREQUEST.fields_by_name['init'].containing_oneof = _AUDIODETECTREQUEST.oneofs_by_name['request']
_AUDIODETECTREQUEST.oneofs_by_name['request'].fields.append(
  _AUDIODETECTREQUEST.fields_by_name['audio'])
_AUDIODETECTREQUEST.fields_by_name['audio'].containing_oneof = _AUDIODETECTREQUEST.oneofs_by_name['request']
DESCRIPTOR.message_types_by_name['AudioInfo'] = _AUDIOINFO
DESCRIPTOR.message_types_by_name['PersistenceConfig'] = _PERSISTENCECONFIG
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.message_types_by_name['InitSessionRequest'] = _INITSESSIONREQUEST
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['AudioDetectRequest'] = _AUDIODETECTREQUEST
DESCRIPTOR.message_types_by_name['DetectionResponse'] = _DETECTIONRESPONSE
DESCRIPTOR.enum_types_by_name['AudioCodec'] = _AUDIOCODEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioInfo = _reflection.GeneratedProtocolMessageType('AudioInfo', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOINFO,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.AudioInfo)
  ))
_sym_db.RegisterMessage(AudioInfo)

PersistenceConfig = _reflection.GeneratedProtocolMessageType('PersistenceConfig', (_message.Message,), dict(
  DESCRIPTOR = _PERSISTENCECONFIG,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.PersistenceConfig)
  ))
_sym_db.RegisterMessage(PersistenceConfig)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)

InitSessionRequest = _reflection.GeneratedProtocolMessageType('InitSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONREQUEST,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.InitSessionRequest)
  ))
_sym_db.RegisterMessage(InitSessionRequest)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

AudioDetectRequest = _reflection.GeneratedProtocolMessageType('AudioDetectRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIODETECTREQUEST,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.AudioDetectRequest)
  ))
_sym_db.RegisterMessage(AudioDetectRequest)

DetectionResponse = _reflection.GeneratedProtocolMessageType('DetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DETECTIONRESPONSE,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.DetectionResponse)
  ))
_sym_db.RegisterMessage(DetectionResponse)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.audio.api.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=681,
  serialized_end=804,
  methods=[
  _descriptor.MethodDescriptor(
    name='stream_audio',
    full_name='ai.cogneed.audio.api.StreamAudioService.stream_audio',
    index=0,
    containing_service=None,
    input_type=_AUDIODETECTREQUEST,
    output_type=_DETECTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)
