# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/predict-api/predict-api-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/predict-api/predict-api-service.proto',
  package='ai.cogneed.api.predict.predictapi',
  syntax='proto3',
  serialized_options=_b('\n!ai.cogneed.api.predict.predictapiP\001'),
  serialized_pb=_b('\n<cogneed-protos/predict/predict-api/predict-api-service.proto\x12!ai.cogneed.api.predict.predictapi\"a\n\x17\x41udioPredictionResponse\x12\x10\n\x08start_ms\x18\x01 \x01(\x03\x12\x0e\n\x06\x65nd_ms\x18\x02 \x01(\x03\x12\x13\n\x0bprobability\x18\x03 \x01(\x01\x12\x0f\n\x07keyword\x18\x04 \x01(\x03\"\x16\n\x14NoPredictionResponse\"\xb1\x01\n\x08Response\x12P\n\nprediction\x18\x01 \x01(\x0b\x32:.ai.cogneed.api.predict.predictapi.AudioPredictionResponseH\x00\x12H\n\x05\x65mpty\x18\x02 \x01(\x0b\x32\x37.ai.cogneed.api.predict.predictapi.NoPredictionResponseH\x00\x42\t\n\x07\x63ontent\"\x88\x01\n\x16\x41udioPredictionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x12\n\nblob_index\x18\x04 \x01(\x03\x12\x10\n\x08use_case\x18\x05 \x01(\t\x12\r\n\x05major\x18\x06 \x01(\t2\x8b\x01\n\x16\x41udioPredictionService\x12q\n\x07predict\x12\x39.ai.cogneed.api.predict.predictapi.AudioPredictionRequest\x1a+.ai.cogneed.api.predict.predictapi.ResponseB%\n!ai.cogneed.api.predict.predictapiP\x01\x62\x06proto3')
)




_AUDIOPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='AudioPredictionResponse',
  full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.start_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.end_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.probability', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.keyword', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=196,
)


_NOPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='NoPredictionResponse',
  full_name='ai.cogneed.api.predict.predictapi.NoPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=220,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='ai.cogneed.api.predict.predictapi.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction', full_name='ai.cogneed.api.predict.predictapi.Response.prediction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='ai.cogneed.api.predict.predictapi.Response.empty', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictapi.Response.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=223,
  serialized_end=400,
)


_AUDIOPREDICTIONREQUEST = _descriptor.Descriptor(
  name='AudioPredictionRequest',
  full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.model_version', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.blob_index', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.use_case', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.major', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=539,
)

_RESPONSE.fields_by_name['prediction'].message_type = _AUDIOPREDICTIONRESPONSE
_RESPONSE.fields_by_name['empty'].message_type = _NOPREDICTIONRESPONSE
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['prediction'])
_RESPONSE.fields_by_name['prediction'].containing_oneof = _RESPONSE.oneofs_by_name['content']
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['empty'])
_RESPONSE.fields_by_name['empty'].containing_oneof = _RESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['AudioPredictionResponse'] = _AUDIOPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['NoPredictionResponse'] = _NOPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['AudioPredictionRequest'] = _AUDIOPREDICTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioPredictionResponse = _reflection.GeneratedProtocolMessageType('AudioPredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.AudioPredictionResponse)
  ))
_sym_db.RegisterMessage(AudioPredictionResponse)

NoPredictionResponse = _reflection.GeneratedProtocolMessageType('NoPredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _NOPREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.NoPredictionResponse)
  ))
_sym_db.RegisterMessage(NoPredictionResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.Response)
  ))
_sym_db.RegisterMessage(Response)

AudioPredictionRequest = _reflection.GeneratedProtocolMessageType('AudioPredictionRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONREQUEST,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.AudioPredictionRequest)
  ))
_sym_db.RegisterMessage(AudioPredictionRequest)


DESCRIPTOR._options = None

_AUDIOPREDICTIONSERVICE = _descriptor.ServiceDescriptor(
  name='AudioPredictionService',
  full_name='ai.cogneed.api.predict.predictapi.AudioPredictionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=542,
  serialized_end=681,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.api.predict.predictapi.AudioPredictionService.predict',
    index=0,
    containing_service=None,
    input_type=_AUDIOPREDICTIONREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOPREDICTIONSERVICE)

DESCRIPTOR.services_by_name['AudioPredictionService'] = _AUDIOPREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)
