# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/g711-decoder/g711-decoder-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import g711_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/g711-decoder/g711-decoder-service.proto',
  package='ai.cogneed.audio.decode.g711',
  syntax='proto3',
  serialized_options=_b('\n\034ai.cogneed.audio.decode.g711P\001'),
  serialized_pb=_b('\nCcogneed-protos/audio-stream/g711-decoder/g711-decoder-service.proto\x12\x1c\x61i.cogneed.audio.decode.g711\x1a-cogneed-protos/audio-stream/common/g711.proto\"X\n\rDecodeRequest\x12\x36\n\x05\x63odec\x18\x01 \x01(\x0e\x32\'.ai.cogneed.audio.decode.g711.G711Codec\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"!\n\x0e\x44\x65\x63odeResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x32y\n\x12G711DecoderService\x12\x63\n\x06\x64\x65\x63ode\x12+.ai.cogneed.audio.decode.g711.DecodeRequest\x1a,.ai.cogneed.audio.decode.g711.DecodeResponseB \n\x1c\x61i.cogneed.audio.decode.g711P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2.DESCRIPTOR,])




_DECODEREQUEST = _descriptor.Descriptor(
  name='DecodeRequest',
  full_name='ai.cogneed.audio.decode.g711.DecodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.audio.decode.g711.DecodeRequest.codec', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.audio.decode.g711.DecodeRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=236,
)


_DECODERESPONSE = _descriptor.Descriptor(
  name='DecodeResponse',
  full_name='ai.cogneed.audio.decode.g711.DecodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.audio.decode.g711.DecodeResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=271,
)

_DECODEREQUEST.fields_by_name['codec'].enum_type = cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2._G711CODEC
DESCRIPTOR.message_types_by_name['DecodeRequest'] = _DECODEREQUEST
DESCRIPTOR.message_types_by_name['DecodeResponse'] = _DECODERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DecodeRequest = _reflection.GeneratedProtocolMessageType('DecodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DECODEREQUEST,
  __module__ = 'cogneed_protos.audio_stream.g711_decoder.g711_decoder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.decode.g711.DecodeRequest)
  ))
_sym_db.RegisterMessage(DecodeRequest)

DecodeResponse = _reflection.GeneratedProtocolMessageType('DecodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _DECODERESPONSE,
  __module__ = 'cogneed_protos.audio_stream.g711_decoder.g711_decoder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.decode.g711.DecodeResponse)
  ))
_sym_db.RegisterMessage(DecodeResponse)


DESCRIPTOR._options = None

_G711DECODERSERVICE = _descriptor.ServiceDescriptor(
  name='G711DecoderService',
  full_name='ai.cogneed.audio.decode.g711.G711DecoderService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=273,
  serialized_end=394,
  methods=[
  _descriptor.MethodDescriptor(
    name='decode',
    full_name='ai.cogneed.audio.decode.g711.G711DecoderService.decode',
    index=0,
    containing_service=None,
    input_type=_DECODEREQUEST,
    output_type=_DECODERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_G711DECODERSERVICE)

DESCRIPTOR.services_by_name['G711DecoderService'] = _G711DECODERSERVICE

# @@protoc_insertion_point(module_scope)
