# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.audio_stream.audio_stream_recorder import audio_stream_recorder_service_pb2 as cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2


class RecordServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.record = channel.unary_unary(
        '/ai.cogneed.record.v1.RecordService/record',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.RecordRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.FromString,
        )
    self.consolidate = channel.unary_unary(
        '/ai.cogneed.record.v1.RecordService/consolidate',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.ConsolidateRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.FromString,
        )


class RecordServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def record(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def consolidate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RecordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'record': grpc.unary_unary_rpc_method_handler(
          servicer.record,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.RecordRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.SerializeToString,
      ),
      'consolidate': grpc.unary_unary_rpc_method_handler(
          servicer.consolidate,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.ConsolidateRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.record.v1.RecordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
